@@ -34,14 +34,17 @@ pub struct FastRoundResultAccountData {
 }
 
 // REQUIRES THE ENTIRE BUFFER, WITH TYPE BYTE
-pub fn fast_from_bytes<T: Sized + AsBytes + FromBytes + Clone>(bytes: &[u8])
--> Result<T, ProgramError> {
-    let len = std::mem::size_of::<T>();
-    let mut buf: Vec<u8> = vec![];
-    buf.extend(&bytes[..len]);
-    let (res, _) = LayoutVerified::<&[u8], T>::new_from_prefix(&buf)
-        .ok_or(ProgramError::InvalidAccountData)?;
-    return Ok(res.clone());
+pub fn fast_from_bytes(bytes: &[u8]) -> Result<FastRoundResultAccountData, ProgramError> {
+    let mut res = FastRoundResultAccountData {
+        ..Default::default()
+    };
+    let mut buf = res.as_bytes_mut();
+    buf.copy_from_slice(&bytes[..buf.len()]);
+    // let len = std::mem::size_of::<T>();
+    // let buf: Vec<u8> = bytes[..len].to_vec().clone();
+    // let (res, _) = LayoutVerified::<&[u8], T>::new_from_prefix(&buf)
+        // .ok_or(ProgramError::InvalidAccountData)?;
+    return Ok(res);
 }
 
 // pub fn borsh_safe_serialize<T: BorshSerialize>(state: &T, type_indicator: SwitchboardAccountType) -> Vec<u8> {
